@@ -11,21 +11,25 @@
 #include <fcitx-utils/standardpath.h>
 
 #include <QDBusPendingCallWatcher>
+#include <QLoggingCategory>
+
+Q_LOGGING_CATEGORY(addonsProxy, "fcitx5.configtool.addonsproxy")
 
 using namespace deepin::fcitx5configtool;
 
 Fcitx5AddonsProxyPrivate::Fcitx5AddonsProxyPrivate(Fcitx5AddonsProxy *parent, fcitx::kcm::DBusProvider *dbus)
     : q(parent), dbusprovider(dbus)
 {
+    qCDebug(addonsProxy) << "Entering Fcitx5AddonsProxyPrivate constructor";
 }
 
 void Fcitx5AddonsProxyPrivate::fetchAddonsFinished(QDBusPendingCallWatcher *watcher)
 {
-    qDebug() << "Entering fetchAddonsFinished";
+    qCDebug(addonsProxy) << "Entering fetchAddonsFinished";
     watcher->deleteLater();
 
     if (watcher->isError()) {
-        qWarning() << "Failed to fetch addons:" << watcher->error().message();
+        qCWarning(addonsProxy) << "Failed to fetch addons:" << watcher->error().message();
         return;
     }
     QDBusPendingReply<fcitx::FcitxQtAddonInfoV2List> reply(*watcher);
@@ -65,29 +69,32 @@ void Fcitx5AddonsProxyPrivate::fetchAddonsFinished(QDBusPendingCallWatcher *watc
     }
 
     Q_EMIT q->requestAddonsFinished();
-    qDebug() << "Finished processing addons data";
+    qCDebug(addonsProxy) << "Exiting fetchAddonsFinished";
 }
 
 Fcitx5AddonsProxy::Fcitx5AddonsProxy(fcitx::kcm::DBusProvider *dbus, QObject *parent)
     : QObject(parent), d(new Fcitx5AddonsProxyPrivate(this, dbus))
 {
+    qCDebug(addonsProxy) << "Entering Fcitx5AddonsProxy constructor";
 }
 
 Fcitx5AddonsProxy::~Fcitx5AddonsProxy() = default;
 
 void Fcitx5AddonsProxy::clear()
 {
+    qCDebug(addonsProxy) << "Entering clear";
     d->nameToAddonMap.clear();
     d->reverseDependencies.clear();
     d->reverseOptionalDependencies.clear();
     d->addonEntryList.clear();
+    qCDebug(addonsProxy) << "Exiting clear";
 }
 
 void Fcitx5AddonsProxy::load()
 {
-    qDebug() << "Loading fcitx5 addons";
+    qCDebug(addonsProxy) << "Entering load";
     if (!d->dbusprovider->controller()) {
-        qWarning() << "DBus controller not available";
+        qCWarning(addonsProxy) << "DBus controller not available for load";
         return;
     }
 
@@ -95,10 +102,12 @@ void Fcitx5AddonsProxy::load()
     auto watcher = new QDBusPendingCallWatcher(call, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, d,
             &Fcitx5AddonsProxyPrivate::fetchAddonsFinished);
+    qCDebug(addonsProxy) << "Exiting load";
 }
 
 QVariantList Fcitx5AddonsProxy::globalAddons() const
 {
+    qCDebug(addonsProxy) << "Entering globalAddons";
     QVariantList ret;
     for (const auto &entry : d->addonEntryList) {
         for (const auto &addonUniqueName : entry.second) {
@@ -115,16 +124,16 @@ QVariantList Fcitx5AddonsProxy::globalAddons() const
             addonMap["optionalDependencies"] = addon.optionalDependencies();
             ret.append(QVariant::fromValue(addonMap));
         }
-        qDebug() << "Addon state changed successfully";
     }
+    qCDebug(addonsProxy) << "Exiting globalAddons with" << ret.size() << "items";
     return ret;
 }
 
 void Fcitx5AddonsProxy::setEnableAddon(const QString &addonStr, bool enable)
 {
-    qDebug() << "Setting addon" << addonStr << "enable state to" << enable;
+    qCDebug(addonsProxy) << "Entering setEnableAddon for addon" << addonStr << "with enable state" << enable;
     if (!d->nameToAddonMap.contains(addonStr)) {
-        qWarning() << "Addon not found:" << addonStr;
+        qCWarning(addonsProxy) << "Addon not found:" << addonStr;
         return;
     }
     
@@ -137,10 +146,12 @@ void Fcitx5AddonsProxy::setEnableAddon(const QString &addonStr, bool enable)
     list.append(state);
                 
     if (list.size()) {
+        qCInfo(addonsProxy) << "Setting addon states and restarting fcitx5.";
         d->dbusprovider->controller()->SetAddonsState(list);
         QProcess p;
         p.start("killall", QStringList() << "fcitx5");
         p.waitForFinished();
         QProcess::startDetached(QString::fromStdString(fcitx::StandardPath::fcitxPath("bindir", "fcitx5")), QStringList());
     }
+    qCDebug(addonsProxy) << "Exiting setEnableAddon";
 }
